import chalk from 'chalk';
import { colors } from './colors';
const defaultConfig = {
  verbose: false,
  silent: false
};
let config = {
  ...defaultConfig
};
const colorError = chalk.hex(colors.error);
const colorWarn = chalk.hex(colors.warn);
const colorVerbose = chalk.hex(colors.verbose);
export function configure(options) {
  config = {
    ...config,
    ...options
  };
}

// Jest is wrapping console.* calls, so we need to get the raw console object
const rawConsole = require('console');
export function error() {
  rawConsole.error(colorError(...arguments));
}
export function warn() {
  if (config.silent) return;
  rawConsole.warn(colorWarn(...arguments));
}
export function log() {
  if (config.silent) return;
  rawConsole.log(...arguments);
}
export function verbose() {
  if (!config.verbose || config.silent) return;
  rawConsole.log(colorVerbose(...arguments));
}
//# sourceMappingURL=logger.js.map